======================================
Using C++ to access an output database
======================================

The following sections describe the architecture of an output database and how to use the Abaqus C++ Application Programming Interface (API) to access data from an output database.

.. toctree::
    :maxdepth: 1
    :caption: Contents

    cpp/about
    cpp/need-what-access
    cpp/style
    cpp/object-model
    cpp/output-object-model
    cpp/compile-link
    cpp/access
    cpp/architecture
    cpp/utility
    cpp/read
    cpp/write
    cpp/exceptions
    cpp/computations
    cpp/improve-efficiency
    cpp/examples